Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4919)

Unified Diff: chrome/browser/extensions/api/feedback_private/feedback_private_api_chromeos_unittest.cc

Issue 2956513004: Rename SingleLogSource to SingleLogFileLogSource (Closed)
Patch Set: Rebased Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/api/feedback_private/feedback_private_api_chromeos_unittest.cc
diff --git a/chrome/browser/extensions/api/feedback_private/feedback_private_api_chromeos_unittest.cc b/chrome/browser/extensions/api/feedback_private/feedback_private_api_chromeos_unittest.cc
index 6764b7ec4df414de6d0886fccfd2b19b3430d79c..ed67e165324b9355c8d2c71b6e36d02c634b7b44 100644
--- a/chrome/browser/extensions/api/feedback_private/feedback_private_api_chromeos_unittest.cc
+++ b/chrome/browser/extensions/api/feedback_private/feedback_private_api_chromeos_unittest.cc
@@ -18,12 +18,12 @@ namespace extensions {
namespace {
+using api::feedback_private::LogSource;
using api::feedback_private::ReadLogSourceResult;
using api::feedback_private::ReadLogSourceParams;
using base::TimeDelta;
-using system_logs::SingleLogSource;
using system_logs::SystemLogsResponse;
-using SupportedSource = system_logs::SingleLogSource::SupportedSource;
+using system_logs::SystemLogsSource;
std::unique_ptr<KeyedService> ApiResourceManagerTestFactory(
content::BrowserContext* context) {
@@ -41,12 +41,12 @@ std::string ParamsToJSON(const ReadLogSourceParams& params) {
return params_json_string;
}
// A dummy SingleLogSource that does not require real system logs to be
// available during testing.
-class TestSingleLogSource : public SingleLogSource {
+class TestSingleLogSource : public SystemLogsSource {
public:
- explicit TestSingleLogSource(SupportedSource type)
- : SingleLogSource(type), call_count_(0) {}
+ explicit TestSingleLogSource(LogSource type)
+ : SystemLogsSource(ToString(type)), call_count_(0) {}
~TestSingleLogSource() override = default;
@@ -66,7 +66,7 @@ class TestSingleLogSource : public SingleLogSource {
// Do not directly pass the result to the callback, because that's not how
// log sources actually work. Instead, simulate the asynchronous operation
// of a SingleLogSource by invoking the callback separately.
base::ThreadTaskRunnerHandle::Get()->PostTask(
FROM_HERE, base::BindOnce(callback, base::Owned(result_map)));
}
@@ -74,7 +74,7 @@ class TestSingleLogSource : public SingleLogSource {
// Instantiates a new instance of this class. Does not retain ownership. Used
// to create a Callback that can be used to override the default behavior of
// SingleLogSourceFactory.
- static std::unique_ptr<SingleLogSource> Create(SupportedSource type) {
+ static std::unique_ptr<SystemLogsSource> Create(LogSource type) {
return base::MakeUnique<TestSingleLogSource>(type);
}
@@ -41,12 +41,12 @@ std::string ParamsToJSON(const ReadLogSourceParams& params) {
return params_json_string;
}
-// A dummy SingleLogSource that does not require real system logs to be
+// A dummy SystemLogsSource that does not require real system logs to be
// available during testing.
@@ -66,7 +66,7 @@ class TestSingleLogSource : public SingleLogSource {
// Do not directly pass the result to the callback, because that's not how
// log sources actually work. Instead, simulate the asynchronous operation
- // of a SingleLogSource by invoking the callback separately.
+ // of a SystemLogsSource by invoking the callback separately.
base::ThreadTaskRunnerHandle::Get()->PostTask(
FROM_HERE, base::BindOnce(callback, base::Owned(result_map)));

Powered by Google App Engine
This is Rietveld 408576698